@@ -10,7 +10,6 @@ The PyOperators package contains the following modules or packages:
 - operators_pywt : (optional) loaded if PyWavelets is present.
 
 """
-
 from .utils import *
 from .utils.mpi import MPI
 from .core import *
@@ -18,19 +17,15 @@ from .fft import *
 from .linear import *
 from .nonlinear import *
 from .operators_mpi import *
+from .operators_pywt import *
 from .proxy import *
 from . import iterative
 from .iterative import pcg
 from .rules import rule_manager
 from .warnings import PyOperatorsWarning
-
-try:
-    from .operators_pywt import *
-except(ImportError):
-    pass
-
 import sys
 import types
+
 __all__ = [f for f in dir() if f[0] != '_' and not isinstance(eval(f),
            types.ModuleType)]
 
@@ -43,4 +38,4 @@ I = IdentityOperator()
 O = ZeroOperator()
 X = Variable('X')
 
-__version__ = u'0.13.6'
+__version__ = u'0.13.12'
