@@ -13,9 +13,6 @@ from .memory import empty
 from .utils import (complex_dtype, isalias, omp_num_threads, product,
                     tointtuple)
 from .utils.ufuncs import multiply_conjugate
-from .warnings import warn, PyOperatorsWarning
-
-__all__ = ['ConvolutionOperator', 'FFTOperator']
 
 try:
     import pyfftw
@@ -25,17 +22,24 @@ try:
     FFTW_WISDOM_MIN_DELAY = 0.1
     _is_fftw_wisdom_loaded = False
 except:
-    warn('The pyFFTW library is not installed.', PyOperatorsWarning)
+    pass
+
+__all__ = ['ConvolutionOperator', 'FFTOperator']
+
+
+# doctest nose fixture
+def setup_module(module):
+    try:
+        import pyfftw
+    except ImportError:
+        from nose.plugins.skip import SkipTest
+        raise SkipTest()
+
 
 # FFTW out-of-place transforms:
 # PRESERVE_INPUT: default except c2r and hc2r
 # DESTROY_INPUT: default for c2r and hc2r, only possibility for multi c2r
 
-OPERATOR_ATTRIBUTES = ['attrin', 'attrout', 'classin', 'classout', 'commin',
-                       'commout', 'reshapein', 'reshapeout', 'shapein',
-                       'shapeout', 'toshapein', 'toshapeout', 'validatein',
-                       'validateout', 'dtype', 'flags']
-
 
 @linear
 @square
@@ -74,6 +78,7 @@ class _FFTWConvolutionOperator(Operator):
             Operator's dtype.
 
         """
+        import pyfftw
         kernel = np.array(kernel, dtype=dtype, copy=False)
         dtype = kernel.dtype
         if dtype.kind not in ('f', 'c'):
@@ -159,6 +164,7 @@ class _FFTWRealConvolutionOperator(Operator):
     """
     def __init__(self, kernel_fft, fplan, bplan, axes, fftw_flag, nthreads,
                  shapein=None, dtype=None, **keywords):
+        import pyfftw
         self.kernel = kernel_fft
         self._fplan = fplan
         self._bplan = bplan
@@ -291,6 +297,7 @@ class _FFTWRealConvolutionTransposeOperator(_FFTWRealConvolutionOperator):
 class _FFTWComplexOperator(Operator):
     def __init__(self, shapein, axes=None, fftw_flag='FFTW_MEASURE',
                  nthreads=None, dtype=complex, **keywords):
+        import pyfftw
         shapein = tointtuple(shapein)
         if axes is None:
             axes = range(len(shapein))
