@@ -1,9 +1,9 @@
 #coding: utf-8
 from __future__ import absolute_import, division, print_function
-import numexpr
-if numexpr.__version__ < '2.0':
-    raise ImportError('Please update numexpr to a newer version >= 2.0.')
-
+try:
+    import numexpr
+except:
+    pass
 import numpy as np
 import pyoperators as po
 from .core import (
@@ -617,11 +617,12 @@ class NumexprOperator(Operator):
     -------
     >>> k = 1.2
     >>> op = NumexprOperator('exp(input+k)', {'k':k})
-    >>> print op(1) == np.exp(2.2)
+    >>> print(op(1) == np.exp(2.2))
     True
 
     """
     def __init__(self, expr, global_dict=None, dtype=float, **keywords):
+        import numexpr
         self.expr = expr
         self.global_dict = global_dict
         if numexpr.__version__ < '2.1':
