@@ -4,29 +4,41 @@ For now only 1D and 2D wavelets are available.
 
 """
 from __future__ import absolute_import, division, print_function
-import numpy as np
-import pywt
 from .core import Operator, CompositionOperator
 from .flags import linear, real
+import numpy as np
+try:
+    import pywt
+    # dict of corresponding wavelets
+    rwavelist = {}
+    for l in pywt.wavelist():
+        if 'bior' in l:
+            rwavelist[l] = 'rbio' + l[-3:]
+        elif 'rbio' in l:
+            rwavelist[l] = 'bior' + l[-3:]
+        else:
+            rwavelist[l] = l
+except ImportError:
+    pass
 
 __all__ = ['WaveletOperator', 'Wavelet2dOperator']
 
-# dict of corresponding wavelets
-rwavelist = {}
-for l in pywt.wavelist():
-    if 'bior' in l:
-        rwavelist[l] = 'rbio' + l[-3:]
-    elif 'rbio' in l:
-        rwavelist[l] = 'bior' + l[-3:]
-    else:
-        rwavelist[l] = l
+
+# doctest nose fixture
+def setup_module(module):
+    try:
+        import pywt
+    except ImportError:
+        from nose.plugins.skip import SkipTest
+        raise SkipTest()
 
 
 @real
 @linear
 class WaveletOperator(Operator):
+    skip_doctest = True
     def __init__(self, wavelet, mode='zpd', level=None, shapein=None,
-                 **keywords):
+                 dtype=float, **keywords):
         """
         1D wavelet decomposition and reconstruction. Wavelet coefficients
         are stored in a vector (ndarray with ndim=1).
@@ -35,7 +47,6 @@ class WaveletOperator(Operator):
         --------
         >>> W = WaveletOperator("haar", level=1, shapein=2)
         >>> W.todense()
-
         array([[ 0.70710678,  0.70710678],
                [ 0.70710678, -0.70710678]])
 
@@ -50,6 +61,7 @@ class WaveletOperator(Operator):
         Wrapping around PyWavelets
 
         """
+        import pywt
         if not isinstance(wavelet, pywt.Wavelet):
             wavelet = pywt.Wavelet(wavelet)
         self.wavelet = wavelet
@@ -63,7 +75,8 @@ class WaveletOperator(Operator):
         self.cumsizes = np.zeros(len(self.sizes) + 1)
         np.cumsum(self.sizes, out=self.cumsizes[1:])
         shapeout = sum(self.sizes)
-        Operator.__init__(self, shapein=shapein, shapeout=shapeout, **keywords)
+        Operator.__init__(self, shapein=shapein, shapeout=shapeout,
+                          dtype=dtype, **keywords)
         if self.wavelet.orthogonal:
             self.set_rule('T,.', '1', CompositionOperator)
 
@@ -89,7 +102,7 @@ class WaveletOperator(Operator):
 @linear
 class Wavelet2dOperator(Operator):
     def __init__(self, wavelet, mode='zpd', level=None, shapein=None,
-                 **keywords):
+                 dtype=float, **keywords):
         """
         2D wavelet decomposition and reconstruction. Wavelet coefficients
         are stored in a vector (ndarray with ndim=1).
@@ -98,7 +111,6 @@ class Wavelet2dOperator(Operator):
         -------
         >>> W = Wavelet2dOperator("haar", level=1, shapein=(2, 2))
         >>> W.todense()
-
         array([[ 0.5,  0.5,  0.5,  0.5],
                [ 0.5,  0.5, -0.5, -0.5],
                [ 0.5, -0.5,  0.5, -0.5],
@@ -115,6 +127,7 @@ class Wavelet2dOperator(Operator):
         Wrapping around PyWavelet
 
         """
+        import pywt
         if not isinstance(wavelet, pywt.Wavelet):
             wavelet = pywt.Wavelet(wavelet)
         self.wavelet = wavelet
@@ -133,7 +146,8 @@ class Wavelet2dOperator(Operator):
         np.cumsum(self.sizes, out=self.cumsizes[1:])
         shapeout = sum(self.sizes)
 
-        Operator.__init__(self, shapein=shapein, shapeout=shapeout, **keywords)
+        Operator.__init__(self, shapein=shapein, shapeout=shapeout,
+                          dtype=dtype, **keywords)
         if self.wavelet.orthogonal:
             self.set_rule('T,.', '1', CompositionOperator)
 
