@@ -6,7 +6,8 @@ from pyoperators import (
     rule_manager, O)
 from pyoperators.utils import ndarraywrap
 from pyoperators.utils.testing import (
-    assert_is, assert_is_instance, assert_is_none, assert_same, assert_is_type)
+    assert_is, assert_is_instance, assert_is_none, assert_same, assert_is_type,
+    skiptest)
 from .common import OPS, ndarray2, attr2
 
 op = Operator()
@@ -68,6 +69,7 @@ def test_zero5():
     assert_equal(oz.shapeout, o.shapeout, 'oz, out')
 
 
+@skiptest
 def test_zero6():
     @flags.linear
     class Op(Operator):
